==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/calendar/view/action/AddInfoDeleteAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.view.action;

import java.util.Date;
import java.util.List;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.MessageBox;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.calendar.action.DeleteAddInfoProperty;
import com.clustercontrol.calendar.bean.AddListTableDefine;
import com.clustercontrol.calendar.view.AddInfoListView;
import com.clustercontrol.util.Messages;

/**
 * ɲþκԤ󥯥饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class AddInfoDeleteAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.calendar.view.action.AddInfoDeleteAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        //ID
        AddInfoListView view = 
        	(AddInfoListView)this.viewPart.getAdapter(AddInfoListView.class);
        String calendarId = view.getComposite().getCalendarId();

        StructuredSelection selection = (StructuredSelection) view
                .getComposite().getTableViewer().getSelection();

        List list = (List) selection.getFirstElement();
        Date from = null;
        Date to = null;
        if (list != null) {
        	from = (Date)list.get(AddListTableDefine.TIME_FROM);
        	to = (Date)list.get(AddListTableDefine.TIME_TO);
        }

        if (calendarId != null & from != null & to != null) {
            // ǧ
            MessageBox box = new MessageBox(this.viewPart.getSite().getShell(),
                    SWT.OK | SWT.CANCEL | SWT.ICON_WARNING);
            box.setText(Messages.getString("confirmed"));
            String[] args = { calendarId };
            box.setMessage(Messages.getString("message.calendar.21", args));

            // ˤѹ򤵤줿硢Ԥ
            if (box.open() == SWT.OK) {

                if (new DeleteAddInfoProperty().delete(calendarId, from, to)) {
                    // 
                    box = new MessageBox(this.viewPart.getSite().getShell(),
                            SWT.ICON_INFORMATION);
                    box.setText(Messages.getString("successful"));
                    box.setMessage(Messages.getString("message.calendar.19"));
                    box.open();
                } else {
                    // 
                    box = new MessageBox(this.viewPart.getSite().getShell(),
                            SWT.ICON_ERROR);
                    box.setText(Messages.getString("failed"));
                    box.setMessage(Messages.getString("message.calendar.20"));
                    box.open();
                }

                // ӥ塼򹹿
                view.update(calendarId);
            }
        }
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/calendar/view/action/AddInfoDeleteAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.view.action;

import java.util.Date;
import java.util.List;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.MessageBox;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.calendar.action.DeleteAddInfoProperty;
import com.clustercontrol.calendar.bean.AddListTableDefine;
import com.clustercontrol.calendar.view.AddInfoListView;
import com.clustercontrol.util.Messages;

/**
 * カレンダ追加情報の削除を行うアクションクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class AddInfoDeleteAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.calendar.view.action.AddInfoDeleteAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        //カレンダIDを取得
        AddInfoListView view = 
        	(AddInfoListView)this.viewPart.getAdapter(AddInfoListView.class);
        String calendarId = view.getComposite().getCalendarId();

        StructuredSelection selection = (StructuredSelection) view
                .getComposite().getTableViewer().getSelection();

        List list = (List) selection.getFirstElement();
        Date from = null;
        Date to = null;
        if (list != null) {
        	from = (Date)list.get(AddListTableDefine.TIME_FROM);
        	to = (Date)list.get(AddListTableDefine.TIME_TO);
        }

        if (calendarId != null & from != null & to != null) {
            // 確認ダイアログを生成
            MessageBox box = new MessageBox(this.viewPart.getSite().getShell(),
                    SWT.OK | SWT.CANCEL | SWT.ICON_WARNING);
            box.setText(Messages.getString("confirmed"));
            String[] args = { calendarId };
            box.setMessage(Messages.getString("message.calendar.21", args));

            // ダイアログにて変更が選択された場合、削除処理を行う。
            if (box.open() == SWT.OK) {

                if (new DeleteAddInfoProperty().delete(calendarId, from, to)) {
                    // 成功報告ダイアログを生成
                    box = new MessageBox(this.viewPart.getSite().getShell(),
                            SWT.ICON_INFORMATION);
                    box.setText(Messages.getString("successful"));
                    box.setMessage(Messages.getString("message.calendar.19"));
                    box.open();
                } else {
                    // 失敗報告ダイアログを生成
                    box = new MessageBox(this.viewPart.getSite().getShell(),
                            SWT.ICON_ERROR);
                    box.setText(Messages.getString("failed"));
                    box.setMessage(Messages.getString("message.calendar.20"));
                    box.open();
                }

                // ビューを更新
                view.update(calendarId);
            }
        }
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}
